==> oaesis-0.74-src.tar.gz: oaesis/src/resource.h <==
#include	<aesbind.h>

#define	WINDOW	0
#define	WMOVER	1
#define	WAPP	2
#define	WFULLER	3
#define	WDOWN	4
#define	WSIZER	5
#define	WRIGHT	6
#define	WLEFT	7
#define	WVSB	8
#define	WVSLIDER	9
#define	WHSB	10
#define	WHSLIDER	11
#define	WINFO	12
#define	TFILLOUT	13
#define	RFILLOUT	14
#define	BFILLOUT	15
#define	WUP	16
#define	SFILLOUT	17
#define	WSMALLER	18
#define	WCLOSER	19
#define	DESKBG	1
#define	MOUSEFORMS	2
#define	MARROW	1
#define	MTEXT_CRSR	2
#define	MBUSY_BEE	3
#define	MFLAT_HAND	4
#define	MPOINT_HAND	5
#define	ALERT	3
#define	AL_DEFAULT	1
#define	AL_BUTTON	2
#define	AL_TEXT	3
#define	MENU	4
#define	MENU_OAESIS	3
#define	MENU_FILE	4
#define	MENU_OPTIONS	5
#define	MENU_INFO	8
#define	MENU_LOADCONF	17
#define	MENU_SAVECONF	18
#define	MENU_STARTPROG	20
#define	MENU_QUIT	22
#define	MENU_WINDCONF	24
#define	MENU_MENUCONF	25
#define	MENU_EVENTCONF	26
#define	FISEL	5
#define	FISEL_ENTBG	1
#define	FISEL_FIRST	2
#define	FISEL_LAST	11
#define	FISEL_OK	12
#define	FISEL_CANCEL	13
#define	FISEL_DIRECTORY	15
#define	FISEL_SELECTION	17
#define	FISEL_DOWN	18
#define	FISEL_SB	19
#define	FISEL_SLIDER	20
#define	FISEL_UP	21
#define	FISEL_DESCR	22
#define	FISEL_BACK	23
#define	INFORM	6
#define	INFOVERSION	6
#define	INFOOK	11
#define	PMENU	7
#define	PMENU_FIRST	1
#define	PMENU_LAST	20
#define	ERROR_GENERAL	0
#define	ERROR_2_3_18	1
#define	ERROR_4	2
#define	ERROR_5	3
#define	ERROR_8_10_11	4
#define	ERROR_15	5
#define	ERROR_16	6

extern	OBJECT	windowtad[];
extern	OBJECT	deskbgtad[];
extern	OBJECT	mouseformstad[];
extern	OBJECT	alerttad[];
extern	OBJECT	menutad[];
extern	OBJECT	fiseltad[];
extern	OBJECT	informtad[];
extern	OBJECT	pmenutad[];

extern char	*fr_string[];

==> oaesis-0.76-src.tar.gz: oaesis/src/resource.h <==
extern char RESOURCE[];

#define	WINDOW	0
#define	WMOVER	1
#define	WAPP	2
#define	WFULLER	3
#define	WDOWN	4
#define	WSIZER	5
#define	WRIGHT	6
#define	WLEFT	7
#define	WVSB	8
#define	WVSLIDER	9
#define	WHSB	10
#define	WHSLIDER	11
#define	WINFO	12
#define	TFILLOUT	13
#define	RFILLOUT	14
#define	BFILLOUT	15
#define	WUP	16
#define	SFILLOUT	17
#define	WSMALLER	18
#define	WCLOSER	19
#define	DESKBG	1
#define	MOUSEFORMS	2
#define	MARROW	1
#define	MTEXT_CRSR	2
#define	MBUSY_BEE	3
#define	MFLAT_HAND	4
#define	MPOINT_HAND	5
#define	MTHIN_CROSS	6
#define	MTHICK_CROSS	7
#define	MOUTLN_CROSS	8
#define	ALERT	3
#define	AL_DEFAULT	1
#define	AL_BUTTON	2
#define	AL_TEXT	3
#define	AL_ICON	4
#define	AICONS	4
#define	AIC_DISK	1
#define	AIC_STOP	2
#define	AIC_EXCLAMATION	3
#define	AIC_QUESTION	4
#define	AIC_INFO	5
#define	MENU	5
#define	MENU_OAESIS	3
#define	MENU_FILE	4
#define	MENU_OPTIONS	5
#define	MENU_INFO	8
#define	MENU_LOADCONF	17
#define	MENU_SAVECONF	18
#define	MENU_STARTPROG	20
#define	MENU_QUIT	22
#define	MENU_WINDCONF	24
#define	MENU_MENUCONF	25
#define	MENU_EVENTCONF	26
#define	FISEL	6
#define	FISEL_ENTBG	1
#define	FISEL_FIRST	2
#define	FISEL_LAST	11
#define	FISEL_OK	12
#define	FISEL_CANCEL	13
#define	FISEL_DIRECTORY	15
#define	FISEL_SELECTION	17
#define	FISEL_DOWN	18
#define	FISEL_SB	19
#define	FISEL_SLIDER	20
#define	FISEL_UP	21
#define	FISEL_DESCR	22
#define	FISEL_BACK	23
#define	INFORM	7
#define	INFOVERSION	6
#define	INFOOK	11
#define	PMENU	8
#define	PMENU_FIRST	1
#define	PMENU_LAST	20
#define	ERROR_GENERAL	0
#define	ERROR_2_3_18	1
#define	ERROR_4	2
#define	ERROR_5	3
#define	ERROR_8_10_11	4
#define	ERROR_15	5
#define	ERROR_16	6
